@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # vim:et sts=4 sw=4
 #
 # ibus-typing-booster - A completion input method for IBus
@@ -795,7 +794,7 @@ def main() -> None:
         profile.enable()
 
     import doctest # pylint: disable=import-outside-toplevel
-    (failed, dummy_attempted) = doctest.testmod()
+    (failed, _attempted, *_extras) = doctest.testmod()
 
     if BENCHMARK:
         profile.disable()
